==> jc-1.4.0.tar.gz: polyglot/types/ClassType.h <==
// public abstract interface polyglot.types.ClassType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b38560af658974f8 polyglot_types_ClassType

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_ClassType_H_
#define _JC_polyglot_types_ClassType_H_

// Typedefs
typedef struct _jc_polyglot_types_ClassType$fields_struct	_jc_polyglot_types_ClassType$fields_struct;
typedef const struct _jc_polyglot_types_ClassType$vtype	_jc_polyglot_types_ClassType$vtype;

// Class fields structure
struct _jc_polyglot_types_ClassType$fields_struct {
	struct _jc_polyglot_types_ClassType__24Kind$object	*ANONYMOUS;
	struct _jc_polyglot_types_ClassType__24Kind$object	*LOCAL;
	struct _jc_polyglot_types_ClassType__24Kind$object	*MEMBER;
	struct _jc_polyglot_types_ClassType__24Kind$object	*TOP__5fLEVEL;
};
extern _jc_polyglot_types_ClassType$fields_struct _jc_polyglot_types_ClassType$class_fields;

// Static methods
extern void _jc_polyglot_types_ClassType$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Vtype
struct _jc_polyglot_types_ClassType$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_polyglot_types_ClassType$vtype _jc_polyglot_types_ClassType$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_ClassType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_ClassType$class_object;

#endif	/* _JC_polyglot_types_ClassType_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/ClassType.h <==
// public abstract interface polyglot.types.ClassType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b38560af658974f8 polyglot_types_ClassType

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_ClassType_H_
#define _JC_polyglot_types_ClassType_H_

// Typedefs
typedef struct _jc_polyglot_types_ClassType$fields_struct	_jc_polyglot_types_ClassType$fields_struct;
typedef const struct _jc_polyglot_types_ClassType$vtype	_jc_polyglot_types_ClassType$vtype;

// Class fields structure
struct _jc_polyglot_types_ClassType$fields_struct {
	struct _jc_polyglot_types_ClassType__24Kind$object	*ANONYMOUS;
	struct _jc_polyglot_types_ClassType__24Kind$object	*LOCAL;
	struct _jc_polyglot_types_ClassType__24Kind$object	*MEMBER;
	struct _jc_polyglot_types_ClassType__24Kind$object	*TOP__5fLEVEL;
};
extern _jc_polyglot_types_ClassType$fields_struct _jc_polyglot_types_ClassType$class_fields;

// Static methods
extern void _jc_polyglot_types_ClassType$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Vtype
struct _jc_polyglot_types_ClassType$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_polyglot_types_ClassType$vtype _jc_polyglot_types_ClassType$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_ClassType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_ClassType$class_object;

#endif	/* _JC_polyglot_types_ClassType_H_ */
